Developer API Reference
=======================

The documentation presented for :class:`qugrad.QuantumSystem` and its child
classes is demonstrates their usage by specifying method arguments. The
underlying methods actually accept ``*args`` to allow developers to extend the
functionality of QuGrad. To aid in extending QuGrad's functionality we include
source code for :class:`qugrad.QuantumSystem` and its child classes below. The
documentation in this source code is focused on extending the functionality
oposed to utilising it.

.. literalinclude:: ../src/qugrad/systems/_systems.py
  :language: python
  :linenos: